==> MIDITrail-Ver.1.2.3-macOS_src.zip: __MACOSX/MIDITrail/Sources/SMIDILib/._SMOutDevCtrl.mm <==
    Mac OS X            	   2  f                                         ATTR                                   com.apple.TextEncoding           7com.apple.metadata:kMDLabel_hj74hzmbp5dqvia6sutnm4tgpq   UTF-8;134217984k[emZJdQch("}?.0DQK`SY8@`[z-xKDl]K[Vڅ,flX}}l/p<>	9أB~x&OF3QYH?n|ɇ't`AD>Ih@cR
     q  q   ]                                                                                                                                                                                                                                                  
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>AntiAliasMode</key>
	<integer>0</integer>
	<key>CaretMode</key>
	<false/>
	<key>CaretPoint X</key>
	<integer>3</integer>
	<key>CaretPoint Y</key>
	<integer>841</integer>
	<key>DocWrapMode</key>
	<integer>0</integer>
	<key>FilePath</key>
	<string>/Users/wada/Documents/Xcode Projects/OSX/MIDITrail/Sources/SMIDILib/SMOutDevCtrl.mm</string>
	<key>IndentWidth</key>
	<integer>4</integer>
	<key>LetterCount</key>
	<integer>80</integer>
	<key>ModeName</key>
	<string>C</string>
	<key>PrintForm_FileFont</key>
	<integer>4</integer>
	<key>PrintForm_FileFontName</key>
	<string>Monaco</string>
	<key>PrintForm_FileFontNameUni</key>
	<string>default</string>
	<key>PrintForm_FileFontSize</key>
	<real>9</real>
	<key>PrintForm_ForceWordWrap</key>
	<true/>
	<key>PrintForm_LineFont</key>
	<integer>4</integer>
	<key>PrintForm_LineFontName</key>
	<string>Monaco</string>
	<key>PrintForm_LineFontNameUni</key>
	<string>default</string>
	<key>PrintForm_LineMargin</key>
	<integer>0</integer>
	<key>PrintForm_PageFont</key>
	<integer>4</integer>
	<key>PrintForm_PageFontName</key>
	<string>Monaco</string>
	<key>PrintForm_PageFontNameUni</key>
	<string>default</string>
	<key>PrintForm_PageFontSize</key>
	<real>9</real>
	<key>PrintForm_PrintFileName</key>
	<true/>
	<key>PrintForm_PrintFont</key>
	<integer>4</integer>
	<key>PrintForm_PrintFontName</key>
	<string>Monaco</string>
	<key>PrintForm_PrintFontNameUni</key>
	<string>default</string>
	<key>PrintForm_PrintFontSize</key>
	<real>9</real>
	<key>PrintForm_PrintLineNumber</key>
	<true/>
	<key>PrintForm_PrintPageNumber</key>
	<true/>
	<key>PrintForm_PrintSeparateLine</key>
	<true/>
	<key>PrintForm_UsePrintFont</key>
	<false/>
	<key>PrintForm_WrapMode</key>
	<integer>0</integer>
	<key>ReturnCode</key>
	<integer>2</integer>
	<key>SelectPoint X</key>
	<integer>7</integer>
	<key>SelectPoint Y</key>
	<integer>841</integer>
	<key>TabWidth</key>
	<integer>4</integer>
	<key>TextEncoding</key>
	<string>UTF-8</string>
	<key>TextFont</key>
	<integer>4</integer>
	<key>TextFontName</key>
	<string>Monaco</string>
	<key>TextFontNameUni</key>
	<string>default</string>
	<key>TextFontSize</key>
	<real>12</real>
	<key>WindowHeight</key>
	<integer>800</integer>
	<key>WindowPosition H</key>
	<integer>836</integer>
	<key>WindowPosition V</key>
	<integer>194</integer>
	<key>WindowWidth</key>
	<integer>800</integer>
	<key>WrapMode</key>
	<integer>0</integer>
	<key>WrapWithLetterCount</key>
	<false/>
	<key>WrapWithLetterCount LetterCount</key>
	<integer>78</integer>
</dict>
</plist>
             I     I      g   	  	  	    g     p  p  g  6J 6J                                    ~ <J%      T  6J           6J    C    z ,\          [ D        q  q   ]     F MMKE   MMKP                
    mi Document Preference

==> MIDITrail-Ver.1.3.1-macOS_src.zip: __MACOSX/MIDITrail/Sources/SMIDILib/._SMOutDevCtrl.mm <==
    Mac OS X            	   2                                           ATTR                                   com.apple.TextEncoding          7com.apple.metadata:kMDLabel_hj74hzmbp5dqvia6sutnm4tgpq        =  com.apple.quarantine UTF-8;134217984k[emZJdQch("}?.0DQK`SY8@`[z-xKDl]K[Vڅ,flX}}l/p<>	9أB~x&OF3QYH?n|ɇ't`AD>Ih@cR
q/0081;5cc55714;Firefox;3BB2B8C0-68C2-4577-9556-8B389F48E633      q  q   ]                                                                                                                                                                                                                                                  
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>AntiAliasMode</key>
	<integer>0</integer>
	<key>CaretMode</key>
	<false/>
	<key>CaretPoint X</key>
	<integer>3</integer>
	<key>CaretPoint Y</key>
	<integer>841</integer>
	<key>DocWrapMode</key>
	<integer>0</integer>
	<key>FilePath</key>
	<string>/Users/wada/Documents/Xcode Projects/OSX/MIDITrail/Sources/SMIDILib/SMOutDevCtrl.mm</string>
	<key>IndentWidth</key>
	<integer>4</integer>
	<key>LetterCount</key>
	<integer>80</integer>
	<key>ModeName</key>
	<string>C</string>
	<key>PrintForm_FileFont</key>
	<integer>4</integer>
	<key>PrintForm_FileFontName</key>
	<string>Monaco</string>
	<key>PrintForm_FileFontNameUni</key>
	<string>default</string>
	<key>PrintForm_FileFontSize</key>
	<real>9</real>
	<key>PrintForm_ForceWordWrap</key>
	<true/>
	<key>PrintForm_LineFont</key>
	<integer>4</integer>
	<key>PrintForm_LineFontName</key>
	<string>Monaco</string>
	<key>PrintForm_LineFontNameUni</key>
	<string>default</string>
	<key>PrintForm_LineMargin</key>
	<integer>0</integer>
	<key>PrintForm_PageFont</key>
	<integer>4</integer>
	<key>PrintForm_PageFontName</key>
	<string>Monaco</string>
	<key>PrintForm_PageFontNameUni</key>
	<string>default</string>
	<key>PrintForm_PageFontSize</key>
	<real>9</real>
	<key>PrintForm_PrintFileName</key>
	<true/>
	<key>PrintForm_PrintFont</key>
	<integer>4</integer>
	<key>PrintForm_PrintFontName</key>
	<string>Monaco</string>
	<key>PrintForm_PrintFontNameUni</key>
	<string>default</string>
	<key>PrintForm_PrintFontSize</key>
	<real>9</real>
	<key>PrintForm_PrintLineNumber</key>
	<true/>
	<key>PrintForm_PrintPageNumber</key>
	<true/>
	<key>PrintForm_PrintSeparateLine</key>
	<true/>
	<key>PrintForm_UsePrintFont</key>
	<false/>
	<key>PrintForm_WrapMode</key>
	<integer>0</integer>
	<key>ReturnCode</key>
	<integer>2</integer>
	<key>SelectPoint X</key>
	<integer>7</integer>
	<key>SelectPoint Y</key>
	<integer>841</integer>
	<key>TabWidth</key>
	<integer>4</integer>
	<key>TextEncoding</key>
	<string>UTF-8</string>
	<key>TextFont</key>
	<integer>4</integer>
	<key>TextFontName</key>
	<string>Monaco</string>
	<key>TextFontNameUni</key>
	<string>default</string>
	<key>TextFontSize</key>
	<real>12</real>
	<key>WindowHeight</key>
	<integer>800</integer>
	<key>WindowPosition H</key>
	<integer>836</integer>
	<key>WindowPosition V</key>
	<integer>194</integer>
	<key>WindowWidth</key>
	<integer>800</integer>
	<key>WrapMode</key>
	<integer>0</integer>
	<key>WrapWithLetterCount</key>
	<false/>
	<key>WrapWithLetterCount LetterCount</key>
	<integer>78</integer>
</dict>
</plist>
             I     I      g   	  	  	    g     p  p  g  6J 6J                                    ~ <J%      T  6J           6J    C    z ,\          [ D        q  q   ]     F MMKE   MMKP                
    mi Document Preference
